==> manage-changan-1.5.70.jar: management/sqls/changan/长安售气日报表/manageSellPay.sql <==
--查询所有购气量和金额
SELECT
	SUM (xianjin) xianjin,
	SUM (saoma) saoma,
	SUM (yinghang) yinghang
FROM
	(
		SELECT
			NVL (SUM(f_preamount), 0) xianjin,
			0 saoma,
			0 yinghang
		FROM
			T_SELLINGGAS
		WHERE
			f_state = '有效'
		AND f_payment = '现金缴费'
		and f_type='卡表收费'
		AND f_operate_date >= TO_DATE (
		'{startDate} 00:00:00',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND f_operate_date <= TO_DATE (
		'{endDate} 23:59:59',
		'yyyy-mm-dd hh24:mi:ss'
	)
		AND { f_filiale != $$ : $ f_filiale = '{f_filiale}' $,
		f_filiale == $$ : $ 1 = 1 $,
		$$ }
	AND { f_outlets != $$ : $ f_outlets = '{f_outlets}' $,
	f_outlets == $$ : $ 1 = 1 $,
	$$ }
AND { op_id != $$ : $ op_id = '{op_id}' $,
 op_id == $$ : $ 1 = 1 $,
 $$ }
AND { op_spot != $$ : $ op_spot = '{op_spot}' $,
 op_spot == $$ : $ 1 = 1 $,
 $$ }
UNION ALL
	SELECT
		0 xianjin,
		NVL (SUM(f_preamount), 0) saoma,
		0 yinghang
	FROM
		T_SELLINGGAS
	WHERE
		f_state = '有效'
	AND f_payment = '扫码支付'
	and f_type='卡表收费'
AND f_operate_date >= TO_DATE (
		'{startDate} 00:00:00',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND f_operate_date <= TO_DATE (
		'{endDate} 23:59:59',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND { f_filiale != $$ : $ f_filiale = '{f_filiale}' $,
	f_filiale == $$ : $ 1 = 1 $,
	$$ }
AND { f_outlets != $$ : $ f_outlets = '{f_outlets}' $,
 f_outlets == $$ : $ 1 = 1 $,
 $$ }
AND { op_id != $$ : $ op_id = '{op_id}' $,
 op_id == $$ : $ 1 = 1 $,
 $$ }
AND { op_spot != $$ : $ op_spot = '{op_spot}' $,
 op_spot == $$ : $ 1 = 1 $,
 $$ }
UNION ALL
	SELECT
		0 xianjin,
		0 saoma,
		NVL (SUM(f_preamount), 0) yinghang
	FROM
		T_SELLINGGAS
	WHERE
		f_state = '有效'
	AND f_payment = '银行缴费'
	and f_type='卡表收费'
	AND f_operate_date >= TO_DATE (
		'{startDate} 00:00:00',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND f_operate_date <= TO_DATE (
		'{endDate} 23:59:59',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND { f_filiale != $$ : $ f_filiale = '{f_filiale}' $,
	f_filiale == $$ : $ 1 = 1 $,
	$$ }
AND { f_outlets != $$ : $ f_outlets = '{f_outlets}' $,
 f_outlets == $$ : $ 1 = 1 $,
 $$ }
AND { op_id != $$ : $ op_id = '{op_id}' $,
 op_id == $$ : $ 1 = 1 $,
 $$ }
AND { op_spot != $$ : $ op_spot = '{op_spot}' $,
 op_spot == $$ : $ 1 = 1 $,
 $$ }
	)

==> manage-changan-1.5.85-4.jar: management/sqls/changan/长安售气日报表/manageSellPay.sql <==
--查询所有购气量和金额
SELECT
	SUM (xianjin) xianjin,
	SUM (saoma) saoma,
	SUM (yinghang) yinghang
FROM
	(
		SELECT
			NVL (SUM(f_preamount), 0) xianjin,
			0 saoma,
			0 yinghang
		FROM
			T_SELLINGGAS
		WHERE
			f_state = '有效'
		AND f_payment = '现金缴费'
		and f_type in ('物联网收费','卡表收费')
		AND f_operate_date >= TO_DATE (
		'{startDate} 00:00:00',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND f_operate_date <= TO_DATE (
		'{endDate} 23:59:59',
		'yyyy-mm-dd hh24:mi:ss'
	)
		AND { f_filiale != $$ : $ f_filiale = '{f_filiale}' $,
		f_filiale == $$ : $ 1 = 1 $,
		$$ }
	AND { f_outlets != $$ : $ f_outlets = '{f_outlets}' $,
	f_outlets == $$ : $ 1 = 1 $,
	$$ }
AND { op_id != $$ : $ op_id = '{op_id}' $,
 op_id == $$ : $ 1 = 1 $,
 $$ }
AND { op_spot != $$ : $ op_spot = '{op_spot}' $,
 op_spot == $$ : $ 1 = 1 $,
 $$ }
UNION ALL
	SELECT
		0 xianjin,
		NVL (SUM(f_preamount), 0) saoma,
		0 yinghang
	FROM
		T_SELLINGGAS
	WHERE
		f_state = '有效'
	AND f_payment = '扫码支付'
    and f_type in ('物联网收费','卡表收费')
AND f_operate_date >= TO_DATE (
		'{startDate} 00:00:00',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND f_operate_date <= TO_DATE (
		'{endDate} 23:59:59',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND { f_filiale != $$ : $ f_filiale = '{f_filiale}' $,
	f_filiale == $$ : $ 1 = 1 $,
	$$ }
AND { f_outlets != $$ : $ f_outlets = '{f_outlets}' $,
 f_outlets == $$ : $ 1 = 1 $,
 $$ }
AND { op_id != $$ : $ op_id = '{op_id}' $,
 op_id == $$ : $ 1 = 1 $,
 $$ }
AND { op_spot != $$ : $ op_spot = '{op_spot}' $,
 op_spot == $$ : $ 1 = 1 $,
 $$ }
UNION ALL
	SELECT
		0 xianjin,
		0 saoma,
		NVL (SUM(f_preamount), 0) yinghang
	FROM
		T_SELLINGGAS
	WHERE
		f_state = '有效'
	AND f_payment = '银行缴费'
    and f_type in ('物联网收费','卡表收费')
	AND f_operate_date >= TO_DATE (
		'{startDate} 00:00:00',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND f_operate_date <= TO_DATE (
		'{endDate} 23:59:59',
		'yyyy-mm-dd hh24:mi:ss'
	)
	AND { f_filiale != $$ : $ f_filiale = '{f_filiale}' $,
	f_filiale == $$ : $ 1 = 1 $,
	$$ }
AND { f_outlets != $$ : $ f_outlets = '{f_outlets}' $,
 f_outlets == $$ : $ 1 = 1 $,
 $$ }
AND { op_id != $$ : $ op_id = '{op_id}' $,
 op_id == $$ : $ 1 = 1 $,
 $$ }
AND { op_spot != $$ : $ op_spot = '{op_spot}' $,
 op_spot == $$ : $ 1 = 1 $,
 $$ }
	)
